#!/bin/bash

COMPAT_MAJOR=("28")
COMPAT_MINOR=("1.0")

COMPAT_PROFILES=("astro" "elroy" "orbitty" "rosie" "rudi" "spacely-IMX274-3CAM" "spacely-IMX185-3CAM" "sprocket-imx274" "sprocket-imx185" "cogswell")

COMPAT_JETSON=("TX1")

CTI_L4T_VER="V018"


#utility functions
chkroot(){

    if [ $EUID -ne 0 ]
    then
        echo "Please run as sudo or root"
        exit 1
    fi
}

chkhost(){

    if [ $( uname -i | grep -c x86) -lt 1 ]; then
        echo "This version of the CTI-L4T BSP must be installed on the x86 Host system"
        exit 1
    fi

}

#check if bsp installed in the correct folder on host machine
chkfolder(){
    
    if [ $(basename $(dirname $(pwd))) != "Linux_for_Tegra_64_tx1" ] || [ $(basename $(pwd)) != "CTI-L4T" ]; then
        echo "This BSP should be extracted in the Linux_for_Tegra_64_tx1 directory"
        echo "of your Jetpack install. This install script  must be run from the"
        echo "Linux_for_Tegra_64_tx1/CTI-L4T directory"
        exit 2
    fi

}


install_dtb(){

    cp ./kernel/dtb/* ../kernel/dtb/

}

install_kernel(){

    cp ./kernel/*Image ../kernel/
    cp ./kernel/kernel_supplements.tbz2 ../rootfs/
    tar -xjf ../rootfs/kernel_supplements.tbz2 -C ../rootfs/
    rm ../rootfs/kernel_supplements.tbz2
}

#install_bl(){

#    cp bl/BCT/* ../bootloader/t186ref/BCT
#   cp bl/cfg/* ../bootloader/t186ref/cfg
    
#    cp -r bl/cti/ ../bootloader/t186ref/ 

#}

install_ver_file(){

    if [ ! -d "../rootfs/etc/cti" ]; then
        mkdir ../rootfs/etc/cti
    fi  

    echo $CTI_L4T_VER > ../rootfs/etc/cti/CTI-L4T.version 

}

print_versions(){

    echo "Supported Version Information"
    echo "  CTI-L4T Board Support Package Version:" $CTI_L4T_VER

    echo "  Supported CTI Products (profiles): "
    for i in ${COMPAT_PROFILES[@]}; do
        echo "    " $i
    done

    echo "  Supported Linux for Tegra Release Versions: "
    for j in ${COMPAT_MINOR[@]}; do
        echo "    " $COMPAT_MAJOR"."$j
    done

    echo "  Supported Nvidia Jetson Module Hardware: "
    for k in ${COMPAT_JETSON[@]}; do
        echo "    " $k
    done

}

#help functions 

usage(){
    echo -e "  Usage: ./install.sh "
    echo -e "  Before installing this BSP, please read the included readme.txt"
    echo -e "  To switch between different products, the TX1 will need to be re-flashed"
    echo -e "  Below are the compatible L4T versions and board profiles:\n"

    print_versions
}


#start
usage

chkroot

chkfolder

tar -pxzf resources.tgz

#install .conf files into Linux_for_Tegra_tx2 

cp conf/* ..

install_dtb

#install_bl

install_kernel

install_ver_file

cp ./flash.sh ..

pushd ..

./apply_binaries.sh

popd

# ensure the files finish copying 
sync

echo "CTI-L4T-$CTI_L4T_VER Installed!"
